@@ -31,8 +31,10 @@ def argument_parser():
     parser = argparse.ArgumentParser()
     # Define expected arguments
     parser.add_argument("command", help="Command method (start or stop)")
-    parser.add_argument("-v", "--verbose", help="activate verbose mode",
-                        action="store_true")
+    parser.add_argument(
+        "-v", "--verbose", help="activate verbose mode", action="store_true")
+    parser.add_argument(
+        "-c", "--config-file", help="path to configuration file")
     # Return list of argument passed in command line
     return parser.parse_args()
 
